# -*- coding: utf8 -*-

from django import forms
from django.core.validators import EmailValidator
from django.core.exceptions import ValidationError
from django.utils.safestring import mark_safe
import re


class ReadOnlyHiddenWidget(forms.Widget):
    input_type = "readonly"

    def render(self, name, value, attrs, renderer=None):
        return mark_safe(
            '<input type="hidden" id="{}" name="{}" value="{}" />\n{}'.format(attrs["id"], name, value, value)
        )

    def _has_changed(self, initial, data):
        return False


class ReadOnlyField(forms.Field):
    widget = ReadOnlyHiddenWidget

    def __init__(self, *args, **kwargs):
        super(ReadOnlyField, self).__init__(*args, **kwargs)

    def clean(self, value):
        return value


class PhoneField(forms.CharField):
    tests = [
        r"^(\d{2})[ \.](\d{2})[ \.](\d{2})[ \.](\d{2})[ \.](\d{2})$",
        r"^(\d{10})$",
    ]
    re_tests = [re.compile(test) for test in tests]

    def clean(self, value):
        super(PhoneField, self).clean(value)
        value = value.strip()
        if not self.required and value == "":
            return ""

        for r in PhoneField.re_tests:
            m = r.match(value)
            if m:
                plat = "".join(m.groups())
                delim = " ".join([plat[i : i + 2] for i in range(0, len(plat), 2)])
                return delim

        raise forms.ValidationError("Ce numéro de téléphone n'est pas valide.")


class LdapBooleanField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        forms.ChoiceField.__init__(self, *args, **kwargs)
        self.choices = [("0", "Non"), ("1", "Oui")]


class RestrictDomaineEmailValidator(EmailValidator):

    message_domain = "Enter a valid email adress with domain in the restricted list"
    code_domain = "invalid_domain"

    def __init__(
        self,
        restrict_domain=None,
        message_domain=None,
        code_domain=None,
        *args,
        **kwargs,
    ):
        super(RestrictDomaineEmailValidator, self).__init__(*args, **kwargs)
        self.restrict_domain = restrict_domain
        if message_domain is not None:
            self.message_domain = message_domain
        if code_domain is not None:
            self.code_domain = code_domain

    def __call__(self, value):
        super(RestrictDomaineEmailValidator, self).__call__(value)

        if self.restrict_domain:
            user_part, domain_part = value.rsplit("@", 1)
            if domain_part not in self.restrict_domain:
                raise ValidationError(self.message_domain, code=self.code_domain)
